"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initReporters = void 0;
const Logger_1 = require("./Logger");
const NpmLogReporter_1 = require("./reporters/NpmLogReporter");
const LogLevel_1 = require("./LogLevel");
const JsonReporter_1 = require("./reporters/JsonReporter");
const AdoReporter_1 = require("./reporters/AdoReporter");
function initReporters(config) {
    // Initialize logger
    let logLevel = config.verbose ? LogLevel_1.LogLevel.verbose : LogLevel_1.LogLevel.info;
    if (config.logLevel) {
        logLevel = LogLevel_1.LogLevel[config.logLevel];
    }
    const reporters = [
        config.reporter === "json"
            ? new JsonReporter_1.JsonReporter({ logLevel })
            : new NpmLogReporter_1.NpmLogReporter({
                logLevel,
                grouped: config.grouped,
                npmLoggerOptions: config.loggerOptions
            }),
    ];
    if (config.reporter === "adoLog") { // Will always include NpmLogReporter and add AdoReporter
        reporters.push(new AdoReporter_1.AdoReporter());
    }
    Logger_1.Logger.reporters = reporters;
    return reporters;
}
exports.initReporters = initReporters;
